@@ -1,7 +1,7 @@
 """
 Type annotations for iotanalytics service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/type_defs/)
 
 Usage::
 
@@ -16,7 +16,6 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     ChannelStatusType,
@@ -1389,7 +1388,7 @@ MessageTypeDef = TypedDict(
     "MessageTypeDef",
     {
         "messageId": str,
-        "payload": Union[bytes, IO[bytes], StreamingBody],
+        "payload": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 
@@ -1545,7 +1544,7 @@ RunPipelineActivityRequestRequestTypeDef = TypedDict(
     "RunPipelineActivityRequestRequestTypeDef",
     {
         "pipelineActivity": "PipelineActivityTypeDef",
-        "payloads": Sequence[Union[bytes, IO[bytes], StreamingBody]],
+        "payloads": Sequence[Union[str, bytes, IO[Any], StreamingBody]],
     },
 )
 
